use std::env::var as env_var;
use std::path::PathBuf;

pub fn whck_dir() -> PathBuf {
    whck_dir_from_env()
    .unwrap_or(
        whck_dir_from_xdg_config()
        .unwrap_or(
            whck_dir_from_home()
            .unwrap_or(
                whck_dir_from_exe()
                .expect("Exhausted all methods to find ~/.config/whck/")
            )
        )
    )
}

pub fn whck_dir_from_env() -> Option<PathBuf> {
    env_var("WHCK_DIR").ok().map(|x| PathBuf::from(x))
}
pub fn whck_dir_from_xdg_config() -> Option<PathBuf> {
    env_var("XDG_CONFIG_HOME").ok().map(|x| PathBuf::from(x).join("whck"))
}
pub fn whck_dir_from_home() -> Option<PathBuf> {
    env_var("HOME").ok().map(|x| PathBuf::from(x).join(".config/whck"))
}
pub fn whck_dir_from_exe() -> Option<PathBuf> {
    //std::env::current_exe().ok().and_then(|x| {
    println!("{:?}", std::env::current_exe());
    std::env::current_exe().ok().and_then(|x| {
        // Canonicalize (resolve symlinks) in case we have a symlink from webdir
        let basepath = x.canonicalize().unwrap();
        let mut components = basepath.components();
        println!("{:?}", components);
        // We have canonicalized so component 0 is "RootDir"
        if let Some(dir) = components.nth(1) {
            if dir.as_os_str().to_str().unwrap() == "home" {
                if let Some(user) = components.next() {
                    return Some(PathBuf::from("/home")
                        .join(user)
                        .join(".config/whck"));
                } else {
                    println!("no user");
                }
            } else {
                println!("Not home");
            }
        }
        return None;
    })
}
